@@ -44,8 +44,60 @@ import org.videolan.media.content.PlayerManager;
 
 public class BDJLoader {
 
+    private static class FontCacheAction extends BDJAction {
+        public FontCacheAction(InputStream is) {
+            this.fontPath = null;
+            this.is = is;
+        }
+        public FontCacheAction(String fontPath) {
+            this.fontPath = fontPath;
+            this.is = null;
+        }
+
+        protected void doAction() {
+            try {
+                if (this.is != null) {
+                    this.cacheFile = addFontImpl(is);
+                } else {
+                    this.cacheFile = addFontImpl(fontPath);
+                }
+            } catch (RuntimeException e) {
+                this.exception = e;
+            }
+        }
+
+        public File execute() {
+            BDJActionManager.getInstance().putCommand(this);
+            waitEnd();
+            if (exception != null) {
+                throw exception;
+            }
+            return cacheFile;
+        }
+
+        private final String fontPath;
+        private final InputStream is;
+        private File cacheFile = null;
+        private RuntimeException exception = null;
+    }
+
     /* called by org.dvb.ui.FontFactory */
     public static File addFont(InputStream is) {
+        if (BDJXletContext.getCurrentContext() == null)
+            return addFontImpl(is);
+        /* dispatch cache request to privileged thread */
+        return new FontCacheAction(is).execute();
+    }
+
+    /* called by org.dvb.ui.FontFactory */
+    public static File addFont(String fontFile) {
+        if (BDJXletContext.getCurrentContext() == null)
+            return addFontImpl(fontFile);
+        /* dispatch cache request to privileged thread */
+        return new FontCacheAction(fontFile).execute();
+    }
+
+    private static File addFontImpl(InputStream is) {
         VFSCache localCache = vfsCache;
         if (localCache != null) {
             return localCache.addFont(is);
@@ -53,8 +105,7 @@ public class BDJLoader {
         return null;
     }
 
-    /* called by org.dvb.ui.FontFactory */
-    public static File addFont(String fontFile) {
+    private static File addFontImpl(String fontFile) {
         VFSCache localCache = vfsCache;
         if (localCache != null) {
             return localCache.addFont(fontFile);
@@ -147,6 +198,15 @@ public class BDJLoader {
                 AppID id = (AppID)ids.nextElement();
                 BDJAppProxy proxy = (BDJAppProxy)db.getAppProxy(id);
                 AppEntry entry = (AppEntry)db.getAppAttributes(id);
+                if (proxy == null) {
+                    logger.error("AppsDatabase corrupted!");
+                    continue;
+                }
+                if (entry == null) {
+                    logger.error("AppsDatabase corrupted!");
+                    proxy.release();
+                    continue;
+                }
                 for (int i = 0; i < appTable.length; i++) {
                     if (id.equals(appTable[i].getIdentifier()) &&
                         entry.getInitialClass().equals(appTable[i].getInitialClass())) {
