@@ -60,6 +60,7 @@ public class Libbluray {
                         if (ctx != null) {
                             return ctx.getXletHome();
                         }
+                        System.err.println("getProperty(user.dir): no context !  " + Logger.dumpStack());
                     }
                     return super.getProperty(key);
                 }
@@ -81,13 +82,6 @@ public class Libbluray {
             System.err.println("hookProperties() failed: " + t);
         }
 
-        /* hook class loading (fix invalid class files) */
-        try {
-            sun.misc.ClassFileTransformer.add(new BDJClassFileTransformer());
-        } catch (Throwable t) {
-            System.err.println("Adding class file transformer failed: " + t);
-        }
-
         /* hook sockets (limit network connections) */
         try {
             BDJSocketFactory.init();
