@@ -1,3 +1,22 @@
+/*
+ * This file is part of libbluray
+ * Copyright (C) 2010  VideoLAN
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
+
 package org.videolan.bdjo;
 
 import java.util.BitSet;
@@ -81,6 +100,7 @@ public class AppEntry implements AppAttributes {
     }
 
     public Locator getServiceLocator() {
+        org.videolan.Logger.unimplemented("AppEntry","getServiceLocator");
         /*
         try {
             String discID = BDJTitleInfoHelper.getCurrent32LengthDiscIDFromC();
