@@ -17,6 +17,10 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ig_decode.h"
 
 #include "pg_decode.h"           // pg_decode_*()
